@@ -1,17 +1,17 @@
 // Copyright (C) 1999-2001 Open Source Telecom Corporation.
-//  
+//
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2 of the License, or
 // (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software 
+// along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
 #include "audiotool.h"
@@ -28,14 +28,13 @@ extern "C" {
 
 static BOOL WINAPI down(DWORD ctrltype)
 {
-	if(delfile)
-	{
+	if(delfile) {
 		remove(delfile);
 		delfile = NULL;
 	}
 	exit(ctrltype);
 	return TRUE;
-}
+	}
 
 #else
 static void down(int signo)
@@ -43,7 +42,7 @@ static void down(int signo)
 	if(delfile)
 		remove(delfile);
 	exit(signo);
-}
+	}
 #endif
 
 }
@@ -63,8 +62,7 @@ static void soundcard(unsigned index)
 		cout << "Sound device inaccessible or unsupported" << endl;
 	else if(!soundcard)
 		cout << "Sound device unavailable" << endl;
-	else
-	{
+	else {
 		info = soundcard->getInfo();
 		cout << "Soundcard Driver: " << info->annotation << endl;
 		if(Audio::isStereo(info->encoding))
@@ -118,8 +116,7 @@ int main(int argc, char **argv)
 {
 	char *cp;
 
-	if(argc < 2)
-	{
+	if(argc < 2) {
 		cerr << "use: audiotool --option [args...]" << endl;
 		exit(-1);
 	}
@@ -160,6 +157,8 @@ int main(int argc, char **argv)
 #endif
 	else if(!stricmp(cp, "-info"))
 		Tool::info(++argv);
+	else if(!stricmp(cp, "-size"))
+		Tool::size(++argv);
 	else if(!stricmp(cp, "-notation") || !stricmp(cp, "-annotation"))
 		Tool::notation(++argv);
 	else if(!stricmp(cp, "-chart"))
