@@ -1,17 +1,17 @@
 // Copyright (C) 1999-2001 Open Source Telecom Corporation.
-//  
+//
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2 of the License, or
 // (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software 
+// along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
 #include "audiotool.h"
@@ -26,50 +26,50 @@ static const char *fname(const char *cp)
 	return cp;
 }
 
-bool Tool::isFile(const char *path)    
+bool Tool::isFile(const char *path)
 {
 #ifdef W32
-        DWORD attr = GetFileAttributes(path);
-        if(attr == (DWORD)~0l)
-                return false;
+	DWORD attr = GetFileAttributes(path);
+	if(attr == (DWORD)~0l)
+		return false;
 
-        if(attr & FILE_ATTRIBUTE_DIRECTORY)
-                return false;
+	if(attr & FILE_ATTRIBUTE_DIRECTORY)
+		return false;
 
-        return true;
+	return true;
 
 #else
-        struct stat ino;
+	struct stat ino;
 
-        if(stat(path, &ino))
-                return false;
+	if(stat(path, &ino))
+		return false;
 
-        if(S_ISREG(ino.st_mode))
-                return true;
+	if(S_ISREG(ino.st_mode))
+		return true;
 
-        return false;
+	return false;
 #endif // WIN32
 }
 
 bool Tool::canAccess(const char *path)
 {
 #ifdef WIN32
-        DWORD attr = GetFileAttributes(path);
-        if(attr == (DWORD)~0l)
-                return false;   
+	DWORD attr = GetFileAttributes(path);
+	if(attr == (DWORD)~0l)
+		return false;
 
-        if(attr & FILE_ATTRIBUTE_SYSTEM)
-                return false;
+	if(attr & FILE_ATTRIBUTE_SYSTEM)
+		return false;
 
-        if(attr & FILE_ATTRIBUTE_HIDDEN)
-                return false;
+	if(attr & FILE_ATTRIBUTE_HIDDEN)
+		return false;
 
-        return true;
-#else 
-        if(!access(path, R_OK))
-                return true;
+	return true;
+#else
+	if(!access(path, R_OK))
+		return true;
 
-        return false;
+	return false;
 
 #endif
 }
@@ -83,12 +83,11 @@ void Tool::info(char **argv)
 	unsigned long size, end;
 	unsigned long minutes, seconds, subsec, scale;
 	char duration[32];
-	
+
 	fn = *argv;
 	if(!strnicmp(fn, "--", 2))
 		++fn;
-	if(!strnicmp(fn, "-framing=", 9))
-	{
+	if(!strnicmp(fn, "-framing=", 9)) {
 		framing = atoi(fn + 9);
 		++argv;
 	}
@@ -96,17 +95,14 @@ void Tool::info(char **argv)
 	{
 		framing = atoi(*(++argv));
 		++argv;
-	} 
+	}
 
-	while(*argv)
-	{
-		if(!isFile(*argv))
-		{
+	while(*argv) {
+		if(!isFile(*argv)) {
 			cout << "audiotool: " << fname(*(argv++)) << ": invalid" << endl;
 			continue;
 		}
-		if(!canAccess(*argv))
-		{
+		if(!canAccess(*argv)) {
 			cout << "audiotool: " << fname(*(argv++)) << ": inaccessable" << endl;
 			continue;
 		}
@@ -120,8 +116,7 @@ void Tool::info(char **argv)
 		if(fn)
 			cout << fn << endl;
 		else
-			switch(info.format)
-			{
+			switch(info.format) {
 			case raw:
 				cout << "raw audio" << endl;
 				break;
@@ -138,7 +133,7 @@ void Tool::info(char **argv)
 				cout << "mpeg audio" << endl;
 				break;
 			}
-		
+
 		cout << "    Encoding: " << getName(info.encoding) << endl;
 		if(isStereo(info.encoding))
 			cout << "    Channels: 2" << endl;
@@ -146,8 +141,7 @@ void Tool::info(char **argv)
 			cout << "    Channels: 1" << endl;
 		if(info.framing)
 			cout << "    Frame Size: " << info.framing << "ms" << endl;
-		if(isLinear(info.encoding))
-		{
+		if(isLinear(info.encoding)) {
 			cout << "    Byte Order: ";
 			if(info.order == __BIG_ENDIAN)
 				cout << "big" << endl;
@@ -169,13 +163,13 @@ void Tool::info(char **argv)
 		end /= 60;
 		minutes = end % 60;
 		end /= 60;
-		snprintf(duration, sizeof(duration), 
+		snprintf(duration, sizeof(duration),
 			"%02ld:%02ld:%02ld.%03ld", end, minutes, seconds, subsec);
 		cout << "    Total Duration: " << duration << endl;
 
 		if(info.headersize)
-			cout << "    Computed Frame Size: " << info.framesize - info.headersize - info.padding << ", header=" << info.headersize << ", padding=" << info.padding << endl;    
-		
+			cout << "    Computed Frame Size: " << info.framesize - info.headersize - info.padding << ", header=" << info.headersize << ", padding=" << info.padding << endl;
+
 		au.close();
 	}
 	exit(0);
